"use strict";
var fs = require("fs");
var child_process_1 = require("child_process");
var util_1 = require("./util");
var httpRequest_1 = require("./httpRequest");
var os_1 = require("os");
var path = require("path");
var crypto = require("crypto");
var keychainName = "csc-" + crypto.randomBytes(16).toString("hex") + "keychain";
var developerCertPath = path.join(os_1.tmpdir(), "developer.p12");
var cscName = null;
function createKeychain(callback) {
    var appleCertPath = path.join(os_1.tmpdir(), "apple.cer");
    util_1.seriesTask(util_1.parallelTask(function (callback) { httpRequest_1.download("https://developer.apple.com/certificationauthority/AppleWWDRCA.cer", appleCertPath, callback); }, function (callback) { httpRequest_1.download(process.env.CSC_LINK, developerCertPath, callback); }, util_1.seriesTask(function (callback) { child_process_1.execFile("security", ["create-keychain", "-p", "travis", keychainName], callback); }, function (callback) { child_process_1.execFile("security", ["unlock-keychain", "-p", "travis", keychainName], callback); }, function (callback) { child_process_1.execFile("security", ["set-keychain-settings", "-t", "3600", "-u", keychainName], callback); })), function (callback) { child_process_1.execFile("security", ["import", appleCertPath, "-k", keychainName, "-T", "/usr/bin/codesign"], callback); }, function (callback) { child_process_1.execFile("security", ["import", developerCertPath, "-k", keychainName, "-T", "/usr/bin/codesign", "-P", process.env.CSC_KEY_PASSWORD], callback); }, extractCommonName)(function (error) {
        util_1.parallelTask(fs.unlink.bind(fs, appleCertPath), fs.unlink.bind(fs, developerCertPath))(function (deleteTempFilesError) {
            callback(error || deleteTempFilesError, {
                cscName: cscName,
                cscKeychainName: keychainName
            });
        });
    });
}
exports.createKeychain = createKeychain;
function extractCommonName(callback) {
    child_process_1.execFile("openssl", ["pkcs12", "-nokeys", "-nodes", "-passin", "pass:" + process.env.CSC_KEY_PASSWORD, "-nomacver", "-clcerts", "-in", developerCertPath], function (error, output, errorOutput) {
        if (error != null) {
            callback(error);
            return;
        }
        var match = output.toString().match(/^subject.*\/CN=([^\/]+)/m);
        if (match == null || match[1] == null) {
            callback("Cannot extract common name from p12");
        }
        else {
            cscName = match[1];
            callback(null);
        }
    });
}
function deleteKeychain(callback) {
    child_process_1.execFile("security", ["delete-keychain", keychainName], callback);
}
exports.deleteKeychain = deleteKeychain;
//# sourceMappingURL=codeSign.js.map