"use strict";
var https = require("https");
var fs_1 = require("fs");
var url_1 = require("url");
var maxRedirects = 10;
function download(url, destination, callback) {
    var done = false;
    doDownload(url, destination, function (error) {
        if (!done) {
            done = true;
            callback(error);
        }
    }, 0);
}
exports.download = download;
function doDownload(url, destination, callback, redirectCount) {
    var parsedUrl = url_1.parse(url);
    var request = https.request({
        protocol: parsedUrl.protocol,
        host: parsedUrl.host,
        port: 443,
        path: parsedUrl.path,
        headers: {
            "User-Agent": "NodeHttpRequest"
        }
    }, function (response) {
        if (response.statusCode >= 400) {
            callback("Request error, status " + response.statusCode + ": " + response.statusMessage);
            return;
        }
        var redirectUrl = response.headers.location;
        if (redirectUrl != null) {
            if (redirectCount < maxRedirects) {
                doDownload(redirectUrl, destination, callback, redirectCount++);
            }
            else {
                callback("Too many redirects (> " + maxRedirects + ")");
            }
            return;
        }
        var downloadStream = fs_1.createWriteStream(destination);
        response.pipe(downloadStream);
        downloadStream.on("finish", function () { downloadStream.close(callback); });
        var ended = false;
        response.on("end", function () {
            ended = true;
        });
        response.on("close", function () {
            if (!ended) {
                callback("Request aborted");
            }
        });
    });
    request.on("socket", function (socket) {
        socket.setTimeout(60 * 1000, function () {
            callback("Request timed out");
            request.abort();
        });
    });
    request.on("error", callback);
    request.end();
}
//# sourceMappingURL=httpRequest.js.map